@@ -1,3 +1,5 @@
-#__init__.py
+"""
+Calibration subpackage modules
+"""
 from .solve_calibration import solve_calibration
 from .apply_calibration import apply_calibration
